AuthHandler class

Constructors

AuthHandler()

Properties

endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String?
getter/setter pair

Methods

isTokenValid() Future<bool>
Metodo per verificare se il token è valido.
login(String studentID, String password) Future<String?>
Metodo per autenticarsi e ottenere il token.
logout() Future<void>
Metodo per annullare l'autenticazione (logout).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited