ExamHandler class

Constructors

ExamHandler({required String token})

Properties

endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final

Methods

getDoableExams(String studentID) Future<List<DoableExam>>
getExamsDone(String studentID) Future<List<Exam>>
Recupera gli esami già sostenuti
getReservedExams(String studentID) Future<List<ReservedExam>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited