TaxHandler class

Constructors

TaxHandler({required String token})

Properties

endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final

Methods

getCurrentIsee(String studentID) Future<Isee>
getIseeHistory(String studentID) Future<List<Isee>>
getPaidTaxes(String studentID) Future<List<Tax>>
getPaymentSlipPDF(String studentID, String taxCode) Future<String>
getTaxes(bool isPaid, String studentID) Future<List<Tax>>
getUnpaidTaxes(String studentID) Future<List<Tax>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited