NewsHandler class

Constructors

NewsHandler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
websiteUrl String
final

Methods

getNews({String locale = 'it', bool withDescription = false, int? limit, int? page, int? maxPage, String? query}) Future<List<News>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited