DoableExam class

Constructors

DoableExam({required int codiceInsegnamento, int? codiceCorsoInsegnamento, int? codiceModuloDidattico, required String descrizione, required double cfu, String? ssd, required bool certificato, required bool superamento})
DoableExam.fromJson(Map<String, dynamic> json)
factory

Properties

certificato bool
final
cfu double
final
codiceCorsoInsegnamento int?
final
codiceInsegnamento int
final
codiceModuloDidattico int?
final
descrizione String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ssd String?
final
superamento bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited