Exam class

Constructors

Exam({required String codiceInsegnamento, String? codiceCorso, String? codiceModulo, required String nomeEsame, required DateTime date, required ExamResult result, required double cfu, required String ssd, required bool certified, required bool authorized, required String academicYear, required bool passed})
Exam.fromJson(Map<String, dynamic> json)
factory

Properties

academicYear String
final
authorized bool
final
certified bool
final
cfu double
final
codiceCorso String?
final
codiceInsegnamento String
final
codiceModulo String?
final
date DateTime
final
hashCode int
The hash code for this object.
no setterinherited
nomeEsame String
final
passed bool
final
result ExamResult
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ssd String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited