Isee class

Constructors

Isee({String? data, bool? redditoEstero, String? protocollo, bool? nonDichiaro, double? valore, String? annoFisc})
Isee.fromJson(Map<String, dynamic> json)
factory

Properties

annoFisc String?
final
data String?
final
hashCode int
The hash code for this object.
no setterinherited
nonDichiaro bool?
final
protocollo String?
final
redditoEstero bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valore double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited