ReservedExam class

Constructors

ReservedExam({required int codiceVerbale, required int codiceAppello, String? tipoPrenotazione, required String codiceCorsoStudi, required String nomeCorsoStudi, required String nomeEsame, required double crediti, required String canale, required String docente, required String facolta, required int annoAccademico, required String dataAppello, String? note, required int numeroPrenotazione, required String dataprenotazione, String? dataInizioPrenotazione, String? dataFinePrenotazione, String? dataSeduta, String? insegnamentoAuto, String? tipologiaAuto, required bool questionario, String? annualita, required String siglaModuloDidattico, required String ssd, required int diviSeduta, String? noteCalendario, String? noteTurno, String? noteTurnoStud, String? modalitaSvolgimento})
ReservedExam.fromJson(Map<String, dynamic> json)
Metodo per convertire una mappa JSON in un oggetto ReservedExam
factory

Properties

annoAccademico int
final
annualita String?
final
canale String
final
codiceAppello int
final
codiceCorsoStudi String
final
codiceVerbale int
final
crediti double
final
dataAppello String
final
dataFinePrenotazione String?
final
dataInizioPrenotazione String?
final
dataprenotazione String
final
dataSeduta String?
final
diviSeduta int
final
docente String
final
facolta String
final
hashCode int
The hash code for this object.
no setterinherited
insegnamentoAuto String?
final
modalitaSvolgimento String?
final
nomeCorsoStudi String
final
nomeEsame String
final
note String?
final
noteCalendario String?
final
noteTurno String?
final
noteTurnoStud String?
final
numeroPrenotazione int
final
questionario bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
siglaModuloDidattico String
final
ssd String
final
tipologiaAuto String?
final
tipoPrenotazione String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Metodo per convertire un oggetto ReservedExam in mappa JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited