Tax class
Constructors
-
Tax({String? code, String? codeCourse, String? descriptionCourse, double? amount, int? academicYear, DateTime? paymentDate, DateTime? expirationDate, String? status, List<
Causal> ? causals, String? type, String? descriptionType, bool? isSecondInstallment}) -
Tax.fromJson(Map<
String, dynamic> json) -
factory
Properties
- academicYear → int?
-
final
- amount → double?
-
final
-
causals
→ List<
Causal> ? -
final
- code → String?
-
final
- codeCourse → String?
-
final
- descriptionCourse → String?
-
final
- descriptionType → String?
-
final
- expirationDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSecondInstallment → bool?
-
final
- paymentDate → DateTime?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
final
- type → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited